export default {
  compile_string(template, variables, string) {
    const tokens_l = string.split('{{')
    const tokens_r = string.split('}}')
    if (tokens_l.length !== tokens_r.length) {
      throw new Error('Malformed template string!', string)
    }
    if (tokens_l.length === 1) {
      return string
    }
    let res = string
    for (let i = 1; i < tokens_l.length; i++) {
      const parts = tokens_l[i].split('}}', 1)
      const token = parts[0]
      if (Array.isArray(variables[token.trim()])) {
        // In order to support arrays, we need to replace the entire string with the array if the token matches
        if (res.includes(`{{${token}}}`)) {
          res = variables[token.trim()]
        }
      } else {
        res = res.replace(`{{${token}}}`, variables[token.trim()])
      }
    }
    return res
  },
  compile_entity(template, variables, ent) {
    if (ent === null) {
      return null
    }
    if (typeof ent === 'object') {
      return this.compile_object(template, variables, ent)
    } else if (Array.isArray(ent)) {
      return this.compile_array(template, variables, ent)
    } else if (typeof ent === 'string') {
      return this.compile_string(template, variables, ent)
    }
    return ent
  },
  compile_object(template, variables, obj) {
    window.console.debug('compile object', obj)
    for (const key of Object.keys(obj)) {
      obj[key] = this.compile_entity(template, variables, obj[key])
    }
    return obj
  },
  compile_array(template, variables, arr) {
    for (let i = 0; i < arr.length; i++) {
      arr[i] = this.compile_entity(template, variables, arr[i])
    }
    return arr
  },
  uuid_idx(item, uuid) {
    if (typeof item === 'object') {
      for (const key in item) {
        if (key === 'idx') {
          item[key] = `${uuid}_${item[key]}`
        } else if (key.endsWith('join_ref')) {
          item[key] = `${uuid}_${item[key]}`
        } else {
          item[key] = this.uuid_idx(item[key], uuid)
        }
      }
    } else if (Array.isArray(item)) {
      for (let i = 0; i < item.length; i++) {
        item[i] = this.uuid_idx(item[i], uuid)
      }
    }
    return item
  },
  compile_transaction(template, variables, uuid) {
    const ta = this.compile_entity(template, variables, template.transaction)
    return this.uuid_idx(ta, uuid)
  }
}
